@@ -129,10 +129,14 @@ class AdminClient(object):
 
 
 def main():
+    options_dict = Tools.get_arguments({
+                                "ip":{"default":"127.0.0.1","help":'adimlite ip'},
+                                "port":{"default":"9000","help":'adimlite port'},
+                                })
     print("welcome use admin lite. (type 'exit' to quit)")
-    options = Tools.parser_argument().parse_args()
-    print("connect to %s %d" % (options.server_ip, int(options.server_port)))
-    client = AdminClient(server_addr=(options.server_ip, int(options.server_port)))
+    ip,port = options_dict.get("ip"), int(options_dict.get("port"))
+    print("connect to %s %d" % (ip,port))
+    client = AdminClient(server_addr=(ip,port))
     client.start()
 
 
